#
# spec file for package gnuradio
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover  3_8_5
%bcond_without docs
Name:           gnuradio
Version:        3.8.5.0
Release:        lp152.108.1
Summary:        GNU software radio
License:        GPL-3.0-or-later
Group:          Productivity/Hamradio/Other
URL:            https://gnuradio.org
Source0:        https://github.com/gnuradio/gnuradio/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# http://www.nathanwest.us/grc_to_37.sh
Source4:        grc_to_37.sh
Source99:       %{name}-rpmlintrc
Patch0:         missing_library.patch
Patch1:         revert-23cece0d0.patch
Patch2:         0001-gr-digital-glfsr.h-drop-boost-cstdint.hpp-and-use-cs.patch
BuildRequires:  alsa-devel
BuildRequires:  cmake >= 3.8
BuildRequires:  cppunit-devel
BuildRequires:  cppzmq-devel
BuildRequires:  fdupes
BuildRequires:  fftw3-threads-devel
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  gsl-devel
BuildRequires:  libSDL-devel
BuildRequires:  libboost_atomic-devel >= 1.53
BuildRequires:  libboost_filesystem-devel >= 1.53
BuildRequires:  libboost_system-devel
BuildRequires:  libgsm-devel
BuildRequires:  libjack-devel
BuildRequires:  libmpir-devel
BuildRequires:  log4cpp-devel
BuildRequires:  ninja
BuildRequires:  orc
BuildRequires:  pkgconfig
BuildRequires:  portaudio-devel
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
BuildRequires:  python3-click
BuildRequires:  python3-click-plugins
BuildRequires:  python3-gobject
BuildRequires:  python3-gobject-cairo
BuildRequires:  python3-mako >= 0.9.1
BuildRequires:  python3-numpy
BuildRequires:  python3-pyaml >= 3.11
BuildRequires:  python3-pycairo
BuildRequires:  python3-qt5-devel
BuildRequires:  python3-six
BuildRequires:  qwt6-qt5-devel
BuildRequires:  swig >= 3.0.8
BuildRequires:  typelib(Gtk) = 3.0
BuildRequires:  typelib(PangoCairo) = 1.0
BuildRequires:  typelib(cairo) = 1.0
BuildRequires:  uhd-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(codec2)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(py3cairo)
BuildRequires:  pkgconfig(volk) >= 2.0
# gr_modtool dependencies
Requires:       python3-click
Requires:       python3-click-plugins
Requires:       python3-mako
Requires:       python3-numpy
Requires:       python3-pyaml >= 3.11
Requires:       python3-qt5
%if %{with docs}
BuildRequires:  doxygen
# TeX is required for formula rendering
BuildRequires:  texlive-dvips
BuildRequires:  texlive-latex
BuildRequires:  tex(newunicodechar.sty)
%endif

%description
GNU Radio is a collection of software that when combined with minimal
hardware, allows the construction of radios where the actual waveforms
transmitted and received are defined by software. What this means is
that it turns the digital modulation schemes used in today's high
performance wireless devices into software problems.

%package     -n libgnuradio-%{sover}
Summary:        Libraries for GNU Radio
Group:          System/Libraries

%description -n libgnuradio-%{sover}
GNU Radio is a collection of software that when combined with minimal
hardware, allows the construction of radios where the actual waveforms
transmitted and received are defined by software. What this means is
that it turns the digital modulation schemes used in today's high
performance wireless devices into software problems.

This package contains the libraries for GNU Radio.

%package        devel
Summary:        Deveopment files for GNU Radio
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       gmp-devel
Requires:       log4cpp-devel

%description    devel
GNU Radio is a collection of software that when combined with minimal
hardware, allows the construction of radios where the actual waveforms
transmitted and received are defined by software. What this means is
that it turns the digital modulation schemes used in today's high
performance wireless devices into software problems.

This package contains libraries and header files for developing
applications that use GNU Radio.

%package        doc
Summary:        GNU Radio documentation
Group:          Documentation/HTML
Requires:       %{name} = %{version}
BuildArch:      noarch

%description    doc
GNU Radio is a collection of software that when combined with minimal
hardware, allows the construction of radios where the actual waveforms
transmitted and received are defined by software. What this means is
that it turns the digital modulation schemes used in today's high
performance wireless devices into software problems.

This package contains documentation for GNU Radio.

%package        examples
Summary:        GNU Radio examples
Group:          Productivity/Hamradio/Other
Requires:       %{name} = %{version}

%description    examples
GNU Radio is a collection of software that when combined with minimal
hardware, allows the construction of radios where the actual waveforms
transmitted and received are defined by software. What this means is
that it turns the digital modulation schemes used in today's high
performance wireless devices into software problems.

This package contains some examples of using GNU Radio.

%prep
%autosetup -p1

# remove buildtime from documentation
sed -i 's|^HTML_TIMESTAMP         = YES|HTML_TIMESTAMP         = NO|' docs/doxygen/Doxyfile.in
sed -i 's|^HTML_TIMESTAMP         = YES|HTML_TIMESTAMP         = NO|' docs/doxygen/Doxyfile.swig_doc.in

# protect the template files from %%cmake macro magic / mangling
find  gr-utils/python/modtool/templates/gr-newmod -name CMakeLists.txt -exec mv '{}' '{}.tmpl' \;

%build
%define __builder ninja
%cmake \
  -DENABLE_GRC=ON \
%ifarch armv6l armv6hl
  -Dhave_mfpu_neon=0 \
%endif
  -DGR_PYTHON_DIR=%{python3_sitearch} \
  -DENABLE_INTERNAL_VOLK:BOOL=OFF
%cmake_build

%install
# move the template files back
find  gr-utils/python/modtool/templates/gr-newmod -name CMakeLists.txt.tmpl -execdir mv '{}' 'CMakeLists.txt' \;

%cmake_install

install -d %{buildroot}%{_docdir}/%{name}
mv %{buildroot}/%{_datadir}/doc/%{name}-*/* %{buildroot}%{_docdir}/%{name}/

%suse_update_desktop_file -r %{buildroot}%{_datadir}/applications/gnuradio-grc.desktop Network HamRadio

install -Dpm 0755 %{SOURCE4} %{buildroot}/%{_bindir}

# Compiled examples are installed as "data", but are arch dependent
install -dm 0755 %{buildroot}%{_libdir}/gnuradio
mv %{buildroot}%{_datadir}/gnuradio/examples %{buildroot}%{_libdir}/gnuradio/

# remove duplicate icons (just keep hicolor)
rm -rf %{buildroot}%{_datadir}/%{name}/grc/freedesktop
rm -rf %{buildroot}%{_datadir}/icons/gnome

%fdupes %{buildroot}%{_docdir}
%fdupes %{buildroot}%{_includedir}
%fdupes %{buildroot}%{_libdir}

%post -n libgnuradio-%{sover} -p /sbin/ldconfig
%postun -n libgnuradio-%{sover} -p /sbin/ldconfig

%files
%license COPYING
%{_bindir}/*
%dir %{_datadir}/gnuradio
%{_datadir}/gnuradio/grc/
%{_datadir}/gnuradio/modtool/
%{_datadir}/gnuradio/themes/
%{_datadir}/gnuradio/fec/
%{_datadir}/icons/hicolor/*/apps/gnuradio-grc.png
%{_datadir}/applications/gnuradio-grc.desktop
%{_datadir}/mime/packages/gnuradio-grc.xml
%{python3_sitearch}/*
%dir %{_sysconfdir}/gnuradio
%dir %{_sysconfdir}/gnuradio/conf.d
%config(noreplace) %{_sysconfdir}/gnuradio/conf.d/*.conf
%dir %{_docdir}/%{name}/
%{_docdir}/%{name}/README*
%{_docdir}/%{name}/CHANGELOG*
# doc package
%exclude %{_docdir}/%{name}/html/
%exclude %{_docdir}/%{name}/xml/
%exclude %{_docdir}/%{name}/*.py
%exclude %{_docdir}/%{name}/*.grc

%files -n libgnuradio-%{sover}
%{_libdir}/libgnuradio*.so.*

%files devel
%{_includedir}/%{name}/
%{_includedir}/pmt/
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc
%{_libdir}/cmake/gnuradio/

%files doc
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/html/
%{_docdir}/%{name}/xml/
%{_docdir}/%{name}/*.py
%{_docdir}/%{name}/*.grc

%files examples
%dir %{_libdir}/gnuradio
%{_libdir}/gnuradio/examples/

%changelog
* Sun Jan  9 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 3.8.5.0
  * GRC
    + GRC now runs on Fedora 35 ... Gtk initialization checks were
    too strict
    + Fix: dependent variables sometimes fail to evaluate
    + Change type aliasing to allow interleaved short/byte to be
    connected to vectors of short/byte. Stricter type checking
    was added previously and caused some blocks to be unconnectable
    when using these types.
    + Account for scale factor when computing drawing area size
    + Tooltips fixed for categories and modules
  * gr-digital
    + Fix yml file for Header/Payload Demux
  * gr-dtv
    + Add energy normalization for DVB-S2X constellations.
  * gr-filter
    + Remove pyqwt and qt4 from filter_design
  * gr-qtgui
    + Enable use of Qwt 6.2
    + Remove unusable int type in Number Sink yml
    + RangeWidget - implement Eng & EngSlider
- Patch 0003-enables-use-of-qwt-6_2.patch removed (applied upstream).
* Tue Oct 19 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable again LTO on %%{arm} as it builds properly now
* Tue Oct  5 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 3.8.4.0
  * Changed
    GRC
    + Fix drag and drop issue with Quartz
    + Fix desync when dragging block
    + Update disabled blocks if they depend on others
    + Allow short and byte as valid types in an enum
    + Fix evaluation of interdependent variables
    modtool
    + Set VERSION_PATH to 0 in new modules, instead of using GIT rev
    + For Python3, return correct exeption ModuleNotFoundError
    instead of ImportError
    gr-blocks
    + trix Interleaver block
    gr-channels
    + Fix "hide" expressions in yml files
    gr-digital
    + Remove unused msg output port from Chunks To Symbols block yml
    gr-fft
    + Add "shift" parameter to Log Power FFT
    gr-qtgui
    + Fix: tags on the last sample were not shown
    gr-video-sdl
    + Fix: U and V channels were reversed on sink blocks
* Tue Aug 31 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- added a patch 0003-enables-use-of-qwt-6_2.patch to build with
  Qwt-6.2.0. The patch was backported from pull request #5034.
- fixed build for Tumbleweed and Factory
* Fri Jun 11 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 3.8.3.1
  * This is a PATCH level revision. The API is compatible with C++
    code written for previous v3.8 releases. ABI (shared library
    signature) is intended to be compatible, so code linked
    against v3.8.3.0 should not require recompilation.
  * Build system
    + Improved messages related to dependencies MPIR and GMP. Only
    one of these packages is required, and the previous error
    messages were confusing.
  * GRC
    + Parameter expressions and/or values can be displayed in blocks
    on the flowgraph. Previously, only values were displayed.
    + Vector length is now correctly applied to all input ports.
    + Validation has been improved. Raw types are validated. Port
    connections are checked by type rather than by item size.
    + Variable names that cause conflicts in Python code (e.g.,
    package names) are rejected.
    + Bus logic fixes.
    + Blocks can no longer be dragged off the screen and lost
    forever.
  * gr-dtv
    + VL-SNR bugs fixed (incorrect constants).
  * gr-qtgui
    + Improve autoscaling for vector sinks.
  * gr_filter_design
    + "File/Save" is disabled until the taps have been computed,
    and the GUI is reset after a save, to make it clearer which
    data is being saved.
    + Entries are hidden for parameters that do not apply to the
    selected filter type.
* Mon Apr 12 2021 Martin Pluskal <mpluskal@suse.com>
- Fix source url
- Use ninja for building
* Mon Mar 22 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 3.8.3.0:
  * Changed on project Scope
    + Preference file path may be set using the GR_PREFS_PATH
    environment variable
    + Lower message latency, previously slow when block aliases
    were used
    + PMT: is_dict() no longer returns True for PMT pairs, only
    for PMT dicts
    + Util gnuradio-config-info gets --print-all for those that
    want it all
    + Allow Thrift versions up thorugh 0.13
    + (internal) Build system improvements and fixes
    + (internal) Reduce Boost usage by replacing bind() with lambdas
    supported in C++11
  * OOT Support
    + Allow override of gr python dir by setting -DGR_PYTHON_DIR
    + Modtool will not try to add duplicate block names in a module
    + Modtool can non-interactively add blocks with no parameters
    (--argument-list="")
    + Modtool will use current installation prefix instead of
    /usr/local as source of templates
  * GRC
    + Better handling of gui hints, avoid hiding widgets in cases
    where some have GUI hints and some do not
    + Dark theme detection fix
    + Add window size option for bokeh gui
  * gr-audio
    + ALSA nperiods default increased to 32 frames to reduce drops
    (can be set in conf file under the audio_alsa section)
  * gr-blocks
    + File Source handles EOF properly in non-seekable files
    (e.g., pipes)
    + File Source handles large files on Windows
    + Several bounds checking and boundary condition improvements
  * gr-digital
    + MSK timing error detector improvement
    + Improvements to correlation estimator example
    + Correlate Access Code will not trigger until it receives
    enough bits to compare to the access code
  * gr-dtv
    + Performance improvements
  * gr-filter
    + Filter designer works with Qt5 and Python3
    + Taps blocks (e.g., Low Pass Filter Taps) now propagate
    parameter changes
  * gr-qtgui
    + Chooser label defaults now correct
    + Frequency Sink max hold plot for half spectrum width option
    shows correctly
    + Number Sink honors setting of 'avg' more consistently
  * gr-uhd
    + Add start time parameter to GRC blocks
    + Add message handler for GPIO control messages
    + Additional master clock rates in GRC blocks
    + UHD source sends tags on center frequency change
  * gr-video-sdl
    + Correct YUV format options
  * gr-zeromq
    + Connections no longer hang when flowgraph stops and other
    end is still connected (ZMQ_LINGER now set)
    + Receipt of bad PMTs logged (instead of exception)
- Patch 0002-boost_qualify_placeholders_with_their_full_namespace.patch
  removed (applied upstream).
* Mon Feb 15 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- LTO segfaults on %%arm, so disable it - boo#1182440
* Mon Dec 14 2020 Martin Hauke <mardnh@gmx.de>
- Drop obsolete "Obsoletes: libgnuradio0"
- Add "BuildRequires: python3-pycairo", needed by the GRC
- Force GRC builds
* Thu Sep 17 2020 Martin Hauke <mardnh@gmx.de>
- Add patches to build with boost >= 1.73.0:
  * 0001-gr-digital-glfsr.h-drop-boost-cstdint.hpp-and-use-cs.patch
  * 0002-boost_qualify_placeholders_with_their_full_namespace.patch
  * revert-23cece0d0.patch
  For details see:
  * https://github.com/gnuradio/gnuradio/pull/3441
  * https://github.com/gnuradio/gnuradio/pull/3566
* Wed Aug 26 2020 Matwey Kornilov <matwey.kornilov@gmail.com>
- Update to version 3.8.2.0:
  * Changed on project Scope:
    + Call SWIG without -modern flag if new enough to make that inherent, thus
    removing warnings
  * GRC
    + Mako templating now strict_undefined
    + Show block comments by default
    + dynamically updated block namespaces (execute imports from templates)
    + Name-lookup detection of dark color themes, adjusted input box color
    scheme
  * gr-dtv
    + dvb_bbscrambler: LUT 8B alignment (private, but relevant for future
    usable optimization)
  * Fixed
  * GRC
    + incorrect "clear console" and "save console" labels
    + generator: flow_graph.py.mako now contains import for print_function for
    compatibility in Py2 generation
    + variable_config.block.yml now properly handles configparser /
    ConfigParser import
    + Change port types of all selected block on key-press cycling, not just
    first one
    + Always check for Python version in flow graph generation, not only in
    specific block types
    + Don't run stale flow graphs
    + Prevent search keystrokes from modifying flowgraph
  * gr-blocks
    + file_sink flushes contents to file on stop()
    + file_meta_sink block YAML: emit proper default PMT dict
    + XMLRPC client/server block templates: use Py3 XMLRPC when possible
  * gr-digital
    + soft_dec_lut_gen now explicitly casts 2.0**prec to int
    + map_bb: add missing definition of static constexpr size_t s_map_size
  * gr-dtv
    + Reduce send_frame_size in UHD examples (broken after UHD v3.13.0.3-rc1)
  * gr-filter
    + logpwrfft YAML was hiding FFT length
    + FFT frequency range calculation was occasionally off due to abuse of
    numpy.arange
  * gr-filter
    + GRC band pass filter taps block: use firdes.complex_band_pass when
    complex
    + firdes.root_raised_cosine gain for unity alpha
  * gr-qtgui
    + qtgui_chooser regained 3.7 capability to set default
    + Frequency Sink hovering now respects set units
    + GRC blocks had optional stream inputs
  * gr-uhd
    + ignore len_tag_name in USRP Source YAML generator python
    + uhd_fft/uhd_siggen_gui: import order of sip and Qt
    + GRC example block errors
  * Added
  * GRC
    + OS X: Meta modifier key support (eq. Ctrl on other platforms)
    + configuration setting show_block_comments
  * gr-analog
    + Signal source cmd port
  * gr-zeromq
    + Message-based ZMQ blocks take bind argument, as necessary for N:1
    patterns. Changes ABI.
* Thu Aug 20 2020 Martin Liška <mliska@suse.cz>
- Use memoryperjob constraint instead of %%limit_build macro.
* Thu Apr 30 2020 Martin Hauke <mardnh@gmx.de>
- Update completely changed the way their tarballs are signed
  Drop signature validation for now.
- Remove file
  * gnuradio-3.8.0.0.tar.xz.asc
  * gnuradio.keyring
* Mon Apr 20 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 3.8.1.0:
  * Changed on Project Scope
    + clang-tidy improvements
  - throw exceptions by value, catch by reference
  - emplace_back where applicable
  - empty() instead of vector::size() == 0
    + use CMake to check for endianness instead of BOOST_BIG_ENDIAN
  * gr-fec
    + scipy becomes optional dependency (for polar channel code construction)
  * gr_modtool
    + use Boost.UTF instead of cppunit
  * Fixed on Project Scope
    + FindQwt paths
    + floatAlmostEqual unittest assert function wrongly passing on
    sequence types
    + Only require boost unittest when testing is enabled
    + FindLOG4CPP typo
    + numpy.fft(pack) imports
    + several scipy imports that can be done with numpy alone
  * gnuradio-runtime
    + block gateway shadowed system port
    + Flaky message passing unit test contained timeout (not the test's job)
    + ctrlport/rpcaggregator & Co: removed storage of references to
    scope-lifetime objects
    + Sine table generation python was wrong
    + get_tags_in_range for delay < (end-start)
    + premature tag pruning
    + release flattened flowgraph after stopping; fixes restartability/shutdown
    issues
  * gr-analog
    + clipping in FM receiver: remove superfluous gain
    + C++ generation for multiple blocks
  * gr-audio
    + portaudio source: lock acquisition
  * gr-blocks
    + rotator VOLK workaround
  * gr-digital
    + map_bb buffer overflow
    + map_bb thread safety
    + additive_scrambler count based reset
  * gr-fec
    + heap corruption in async_decoder
    + cc_encoder was broken for constraint lengths > 8
  * gr-fft
    + restore Boost 1.53 compat
  * gr-qtgui
    + no longer requiring unnecessary key in edit_box_msg
  * gr-uhd
    + fixed examples under Py3
    + multichannel objects not populating channels
  * gr_modtool
    + wrong use of input -> raw_input
    + allow empty argument list
    + testing
    + check for and deny TSB under Python
    + QA addition bugs
    + correct path for C++ QA tests
  * GRC
    + several issues with YAML files
    + nested objects now properly populate namespaces
    + comments now included in block bounds calculation
    + Wiki documentation link removed from OOT blocks' docs tab
    + Dragging connections to auto-hide ports works now
    + generated and re-generated several example flowgraphs
    + bokeh_layout module name
    + Revert toggle buttons to text entry for bool block props, allowing GRC
    + variables to be used
  * Added on Project Scope
    + Codec2 development branch / future compat
    + Boost 1.71 compat
    + CI now checks for formatting
    + gnuradio-runtime
    + dot graphs now contain message edges
    + Python wrapping for blocks' set_affinity and {g,s}et_alias
  * gr-uhd
    + UHD Filter API
  * GRC
    + block affinity, buffer sizes available as advanced options for blocks
    + testing
    + Python snippets (please snippet responsibly!)
    + show_id flag added to embedded python blocks, Probes
    + global option to toggle showing of IDs
    + Help "Keyboard Shortcut" entry
* Tue Dec 17 2019 Torsten Ohlenforst <torsten.ohlenforst@pretzel-solutions.com>
- Added missing dependency to package python3-pyaml.
* Thu Sep 19 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use correct QWT dependency, qwt6-devel refers to the Qt4 version on
  Leap 15.0/15.1, qwt6-qt5-devel also works for TW.
- Avoid mangled CMakeLists.txt files in gr_modtool template.
- Update rpmlintrc (changed gr_modtool template directory).
- Move arch dependent examples to _libdir, clean rpmlintrc
* Thu Sep 19 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use pkgconfig(py3cairo) to specify pycairo dependency, package got
  renamed between Leap 15.x and TW, and pkgconfig(py3cairo) fits both.
- Add log4cpp-devel to -devel Requires, always required by gr-runtime.
* Wed Sep 18 2019 Martin Hauke <mardnh@gmx.de>
- Use correct shared library name
* Thu Sep 12 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 3.8.0.0:
  * Changed on Project Scope
    + C++11
    + merged the wholeness of the next branch
    + Dependency version bumps: CMake, GCC, MSVC, Swig, Boost
    + New dependencies: MPIR/GMP, Qt5, gsm, codec2
    + Removed dependencies: libusb, Qt4, CppUnit
    + Python: Python 2 & Python 3 compatible. 3.8 will be the last Py2k-compatible
    + release series
    + gengen was replaced by templates (if you don't know gengen, don't do any
    + research; save yourself that sorrow)
    + Modern CMake (as far as feasible at this point)
    + VOLK version updated to v2.0.0
    + .clang-format file now dictates coding style
    + clang-format'ed the whole tree.
    + installed CMake files now tell about configuration
  * gnuradio-runtime
    + reworked fractional tag time handling, especially in the context of resamplers
  * GRC
    + C++ generation as option
    + YAML instead of XML
    + removed blks2
    + much better canvas tooling
    + consistent gobject usage
    + ROUNDED ARROWS
  * gr-qtgui
    + moving from Qt4 to Qt5
  * gr-utils
    + gr_modtool now vastly improved
  * gr-vocoder
    + improved versatility
    + removed in-tree libgsm, libcodec2, use system-wide libs
  * Removed
    + Project Scope: Modules gr-comedi, gr-fcd and gr-wxgui are gone
    + gr-comedi: nobody could remember who used this, or for what. It has seen 0
    active code contributions in the 3.7 lifecycle
    + gr-digital: python-based packet_encoder and related tools: Bugs that were
    sporadic and never fixed, so after long deprecation, we're removing it
    + gr-fcd: since it's currently untestable by the CI, it's being removed, as
    there was no code contributions. Generally, we strive to include all
    batteries with GNU Radio. Re-integration within a more general SDR interface
    would be desirable.
    + gr-utils: removed PyQwt (dead) based tools
    + gr-wxgui: Unmaintained, breaks on increasingly many systems, always was slower than
    Qtgui. We've been starting to tell people to migrate to Qt since at
    least 2015. Now, we're finally removing it.
- Packaging changes:
  * Use system libvolk, now packaged separately
  * Cleanup spec file, mostly Qt4 and WxWidgets related
  * Use Python3
  * Patches:
  - rebased missing_libraries.patch
  - Drop obsolete qt5-maint-0001-CMake-Update-required-minimum-version-to-2.8.12.patch
  - Drop obsolete qt5-maint-0002-CMake-FindQwt-Find-the-Qt5-version-of-QWT-instead-of.patch
  - Drop obsolete qt5-maint-0003-gr-qtgui-update-for-Qt5.patch
  - Drop obsolete qt5-maint-0004-grc-Generate-Python-scripts-that-use-PyQt5.patch
  - Drop obsolete qt5-maint-0005-gr-qtgui-Add-a-workaround-for-an-upstream-bug-of-uic.patch
  - Drop obsolete qt5-maint-0006-qtgui-fixed-examples-for-Qt5-compatibility.patch
  - Drop obsolete qt5-maint-0007-qtgui-Fixes-for-edit_box_msg-to-work-with-QT5.patch
  - Drop obsolete qt5-maint-0008-gr-qtgui-Allow-build-with-Qt4-or-Qt5-default.patch
  - Drop obsolete qt5-maint-0009-gr-qtgui-Fix-PyQt-4-5-include-in-XMLs-for-GRC.patch
  - Drop obsolete qt5-maint-0010-gr-qtgui-Fix-range.py-to-work-with-both-Qt4-and-Qt5.patch
  - Drop obsolete qt5-maint-0011-gr-qtgui-Re-introduce-some-Qt4-specific-code.patch
  - Drop obsolete qt5-maint-0012-grc-Fix-generation-of-Python-code-for-Qt4-and-Qt5.patch
  - Drop obsolete qt5-maint-0013-grc-replace-templated-xml-files-with-search-and-repl.patch
  - Drop obsolete qt5-maint-0014-qtgui-replace-templated-xml-files-with-search-and-re.patch
  - Drop obsolete qt5-maint-0017-qtgui-fix-stylesheet-for-qt5.patch
  - Drop obsolete qt5-maint-0019-qtgui-fixed-apps-for-Qt5-compatibility.patch
  - Drop obsolete qt5-maint-0021-gnuradio-runtime-ctrlport-qt5.patch
  - Drop obsolete qt5-maint-0022-gr-uhd-qt5.patch
  - Drop obsolete qt5-maint-0023-gr-qtgui-util.patch
  - Drop obsolete qt5-maint-0024-gr-qtgui-restoreGeometry.patch
  - Drop obsolete 0001-Add-the-include-path-used-by-the-openSUSE-package.patch
* Mon Apr 29 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add some missing optional dependencies: libgsm and codec2.
* Mon Apr 29 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patches to build gnuradio using Qt5 on openSUSE > 1500:
  - qt5-maint-0001-CMake-Update-required-minimum-version-to-2.8.12.patch
  - qt5-maint-0002-CMake-FindQwt-Find-the-Qt5-version-of-QWT-instead-of.patch
  - qt5-maint-0003-gr-qtgui-update-for-Qt5.patch
  - qt5-maint-0004-grc-Generate-Python-scripts-that-use-PyQt5.patch
  - qt5-maint-0005-gr-qtgui-Add-a-workaround-for-an-upstream-bug-of-uic.patch
  - qt5-maint-0006-qtgui-fixed-examples-for-Qt5-compatibility.patch
  - qt5-maint-0007-qtgui-Fixes-for-edit_box_msg-to-work-with-QT5.patch
  - qt5-maint-0008-gr-qtgui-Allow-build-with-Qt4-or-Qt5-default.patch
  - qt5-maint-0009-gr-qtgui-Fix-PyQt-4-5-include-in-XMLs-for-GRC.patch
  - qt5-maint-0010-gr-qtgui-Fix-range.py-to-work-with-both-Qt4-and-Qt5.patch
  - qt5-maint-0011-gr-qtgui-Re-introduce-some-Qt4-specific-code.patch
  - qt5-maint-0012-grc-Fix-generation-of-Python-code-for-Qt4-and-Qt5.patch
  - qt5-maint-0013-grc-replace-templated-xml-files-with-search-and-repl.patch
  - qt5-maint-0014-qtgui-replace-templated-xml-files-with-search-and-re.patch
  - qt5-maint-0017-qtgui-fix-stylesheet-for-qt5.patch
  - qt5-maint-0019-qtgui-fixed-apps-for-Qt5-compatibility.patch
  - qt5-maint-0021-gnuradio-runtime-ctrlport-qt5.patch
  - qt5-maint-0022-gr-uhd-qt5.patch
  - qt5-maint-0023-gr-qtgui-util.patch
  - qt5-maint-0024-gr-qtgui-restoreGeometry.patch
- Add 0001-Add-the-include-path-used-by-the-openSUSE-package.patch
  for the Qt5 build.
* Mon Apr 22 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 3.7.13.5
  * Project Scope - fixed PMT: in multiple places, we triggered undef.
    behaviour by accessing the first element of potentially empty
    uvectors
  * gr-audio - fixed Windows audio for higher output multiples broken
  * gr-blocks - fixed QA: udp_source_sink flakiness
  * gr-dtv - fixed sveral broken optimizations
  - fixed 64-APSK parti	ally wrong ordering
  - fixed OOB access in interleaver
  - fixed uncovered worst case LDPC LUT generation
  * gr-qtgui - fixed compiler Warnings
  * gr-fec - fixed polar_encoder/_common: Memory leak
  * gr-uhd - fixed GRC bindings: DC filter was could not be disabled
    with IQ imbalance correction disabled
  * gnuradio-runtime - ctrlport: added int64 for rpcbasic_inserter
  * GRC - Removed generation time from generated python code
* Sun Mar 24 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Fix building with Boost 1.69
* Tue Feb  5 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update _constraints to include minimal disk size
* Thu Aug 30 2018 guillaume.gardet@opensuse.org
- Disable explictly neon on armv6 to fix build
* Thu Aug 30 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add _constraints for ARM to speed-up build
* Wed Jul 18 2018 wk@ire.pw.edu.pl
- Fixed missing space in specfile
* Wed Jul 18 2018 mpluskal@suse.com
- Update source urls
- Use gpg to verify sources
- Modernise spec file with spec-cleaner
* Tue Jul 17 2018 wk@ire.pw.edu.pl
- Update to version 3.7.13.4
  * Fix Boost 1.67 linking issue
  * Logging - fixed issues where messages weren't properly written
    to stdout/stderr due to incorrect strings
  * gr-analog - `fmdet_cf`'s derivative coefficients were wrong.
  * gr-blocks - `skiphead` used to incorrectly handle tags,
    now properly shifts
  * gr-digital - `qa_packet_format`: Unit test used to potentially
    lock up due to incorrect conditionals
  - `clock_recovery_cc`, `crc32_bb`: Accessing the `[0]` element
    of an empty vector is UB, even if you don't use the result
    afterwards.
  * gr-fec - `polar_encoder`/`_common`: Fixed multiple out-of-bound
    accesses due to insufficient vector length checks
  * gr-filter - `fft_filter`, `filter_delay`: Accessing the `[0]`
    element of an empty vector is UB, even if you don't use the
    result afterwards.
- Patch missing_libraries.patch modified
* Fri Jun 15 2018 mardnh@gmx.de
- Update to version 3.7.13.3
  * For non-C++11 compilers, the new cstdint include doesn't work
    out; conditionalized it.
- Remove patch:
  * boost_161.patch (not longer needed)
* Fri Jun  1 2018 mardnh@gmx.de
- Update to version 3.7.13.2
  Fixed:
  * boost::posix_time::[milli]second takes integer numbers, and we
    now at least cast the floats to integers, as Boost 1.67 forced
    us to realize we're (incorrectly) using floating point her
  GRC:
  * Fixed GRC bug which broke WX and Qt (by altering the template
    code), in multiple (less than awesome) steps
  gr-blocks:
  * float_array_to_int: int32 limits were wrongly hardcoded.
  * Fixed the undefined behaviour happening in float_to_complex when
    accessing the second input_items element in the single-input case
* Tue May 29 2018 adam.majer@suse.de
- boost_161.patch: fix compilation with Boost 1.67 (bsc#1089806)
- missing_library.patch: hack to fix linking with required
  libraries.
- use memory-constraints package instead of _constraints
* Mon Apr  2 2018 mardnh@gmx.de
- Update to version 3.7.12.0
  * see /usr/share/doc/packages/gnuradio/CHANGELOG.md
- Remove Patches (not longer needed):
  * CMake-set-C++-standard-to-c++11-and-C-standard-to-C99.diff
  * 0001-gr-fec-switch-possible-C-11-code-from-constexpr-to-j.patch
- Update URLs
* Tue Dec 12 2017 mpluskal@suse.com
- Ignore openssl-1_0_0 for build as temporary workaround for
  Factory unresolvable state
* Mon May 22 2017 mardnh@gmx.de
- Add patches to fix builds on Factory
  + 0001-gr-fec-switch-possible-C-11-code-from-constexpr-to-j.patch
  + CMake-set-C++-standard-to-c++11-and-C-standard-to-C99.diff
* Wed Mar  8 2017 wk@ire.pw.edu.pl
- update to version 3.7.11
* Mon Mar  6 2017 dmitry_r@opensuse.org
- Fix README files installation
* Thu Oct 20 2016 jengelh@inai.de
- Rename soname macro to sover because it did not reflect the
  SONAME.
- RPM group reclassification
* Sat Sep  3 2016 wk@ire.pw.edu.pl
- update to version 3.7.10.1
* Sun Aug  7 2016 wk@ire.pw.edu.pl
- update to version 3.7.10
- patch gnuradio-3.7.9.2-gcc6.patch removed
  * breaks build on Leap 42.2 and Tumbleweed
* Mon Jul 25 2016 wk@ire.pw.edu.pl
- update to version 3.7.9.3
* Thu Jun 23 2016 i@marguerite.su
- add patch: gnuradio-3.7.9.2-gcc6.patch
  * fix 'constexpr' needed for in-class initialization of static
    data member of non-integral type
* Mon Jun 20 2016 dmitry_r@opensuse.org
- Use wxPython 3.0 for Tumbleweed
* Fri Apr 29 2016 wk@ire.pw.edu.pl
- update to version 3.7.9.2
- remove volk-cmake-3.5.patch not needed (applied upstream)
* Tue Mar 22 2016 dmitry_r@opensuse.org
- Fix build with cmake 3.5
  * volk-cmake-3.5.patch
* Sat Feb 13 2016 wk@ire.pw.edu.pl
- update to version 3.7.9.1
* Thu Dec 31 2015 wk@ire.pw.edu.pl
- update to version 3.7.9
* Sat Oct 31 2015 wk@ire.pw.edu.pl
- update to version 3.7.8.1
* Sun Aug 16 2015 wk@ire.pw.edu.pl
- update to version 3.7.8
* Sat May 16 2015 wk@ire.pw.edu.pl
- update to version 3.7.7.1
* Mon Dec  8 2014 stefan.bruens@rwth-aachen.de
- Return options.xml to main package [bnc#908744]
* Thu Dec  4 2014 dmitry_r@opensuse.org
- Set libgnuradio0 as obsolete
* Fri Nov 28 2014 stefan.bruens@rwth-aachen.de
- split out libvolk library package
* Tue Nov 25 2014 stefan.bruens@rwth-aachen.de
- split out wxWidgets dependent parts
  The wxWidgets graphics system will be deprecated with GR 3.8,
  and pulls in a lot of dependencies
- adjust soname to adhere to library packaging policy
* Wed Nov 12 2014 dmitry_r@opensuse.org
- Use -j2 for make
- Delete source url for conversion script
* Wed Oct 22 2014 wk@ire.pw.edu.pl
- update to version 3.7.5
- bugfix release
* Fri Sep 19 2014 wk@ire.pw.edu.pl
- update to version 3.7.5
- patch gnuradio-implicit-fortify-decl.patch removed (applied upstream)
* Tue Sep  9 2014 coolo@suse.com
- disable parallal build - it's too unreliable (due to memory pressure
  on OBS workers)
* Thu Aug 28 2014 dmitry_r@opensuse.org
- Update grc_to_37.sh script to version 0.2
* Thu Aug 28 2014 opensuse@dstoecker.de
- add grc_to_37.sh script to package
* Mon Aug 25 2014 dmitry_r@opensuse.org
- Add missed texlive dependencies
- Fix linking
- Re-enable UHD support
* Wed Aug 20 2014 dmitry_r@opensuse.org
- Update to version 3.7.4
- Remove OBS source service
- Use %%cmake macros
- Enable parallel build
- Remove buildtime from documentation
- Fix implicit definitions of special functions
  * gnuradio-implicit-fortify-decl.patch
- Disable UHD support
- Add _constraints to set required memory to 4Gb
- Use FFTW3 with multithreading support
* Sun Apr  6 2014 wk@ire.pw.edu.pl
- update to version 3.7.3
* Thu Dec 12 2013 dl8fcl@darc.de
- update to version 3.7.2.1
  bug-fix release with no new features
* Sun Nov 10 2013 dl8fcl@darc.de
- update to version 3.7.2
  use qwt6 for all openSUSE versions
* Sat Sep 21 2013 dl8fcl@darc.de
- use qwt5 for openSUSE_13.1
* Sat Aug 31 2013 dl8fcl@darc.de
- update to version 3.7.1
  shared libraries are in a seperated rpm
  changelog is in a seperated file
* Sat Jul  6 2013 wk@ire.pw.edu.pl
- updated to release 3.6.5.1
* Thu May 30 2013 wk@ire.pw.edu.pl
- updated to release 3.6.5
* Fri Mar 29 2013 wk@ire.pw.edu.pl
- updated to release 3.6.4.1
* Sat Mar 16 2013 wk@ire.pw.edu.pl
- updated to release 3.6.4
* Sat Mar  2 2013 wk@ire.pw.edu.pl
- updated to release 3.6.3.1
* Sun Jan 13 2013 wk@ire.pw.edu.pl
- updated to release 3.6.3 (version number patched in source)
* Thu Nov  1 2012 wk@ire.pw.edu.pl
- use Qwt6 if possible
* Tue Oct 30 2012 wk@ire.pw.edu.pl
- heavily modified for actual release
- some parts taken from gnuradio package by surligas and from Fedora package
* Sat Jun  7 2008 dl9pf@gmx.de
- Imported into Build Service
